@@ -48,6 +48,7 @@ NEMO_ACTION_TEMPLATE = """[Nemo Action]
 Name=${name}
 Comment=${comment}
 Exec=${absolute_path} %F
+Icon-Name=${nemo_icon_name}
 Selection=S
 Extensions=${extensions};
 Quote=double
@@ -65,16 +66,32 @@ Name=${name}
 Exec=${absolute_path} %F
 """
 
+CAJA_ACTION_TEMPLATE = """[Desktop Entry]
+Type=Action
+Description=${comment}
+Tooltip=${comment}
+Name=${name}
+Profiles=${identifier};
+Icon=${caja_icon_name}
+
+[X-Action-Profile ${identifier}]
+MimeTypes=${mimetypes};
+Exec=${absolute_path} %F
+Name=${name}
+"""
+
 HELP = dict(
     name="The desired name of the menu entry",
     comment="Comment for the action (Nemo, …)",
+    nemo_icon_name="Icon name for Nemo",
+    caja_icon_name="Icon name for Caja",
     absolute_path="Absolute path of the script to integrate",
     relative_path="Relative path of the script to integrate",
     extensions="Semicolon-separated list of handled file extensions"
     " (Nemo, …)",
     mimetypes="Semicolon-separated list of handled file mime types"
     " (Dolphin, …)",
-    identifier="Internal identifier in the desktop file (Dolphin, …)",
+    identifier="Internal identifier in the desktop file (Caja, Dolphin, …)",
 )
 
 
@@ -157,6 +174,7 @@ class BaseFileManager:
     name = "Unknown File Manager"
     config_directory = ".local/share/unknown-file-manager"
     subdirs = {ACTION: "actions", SCRIPT: "scripts"}
+    explicit_directories = {}
     capabilities = ()
     action_template = ""
     executable = "/bin/false"
@@ -185,9 +203,15 @@ class BaseFileManager:
             )
         #
         self.check_availability()
-        target_directory_path = (
-            self.config_path / self.subdirs[integration_mode]
-        )
+        try:
+            explicit_subpath = self.explicit_directories[integration_mode]
+        except KeyError:
+            target_directory_path = (
+                self.config_path / self.subdirs[integration_mode]
+            )
+        else:
+            target_directory_path = pathlib.Path.home() / explicit_subpath
+        #
         try:
             install_method = getattr(self, f"install_{integration_mode}")
         except AttributeError as error:
@@ -211,8 +235,8 @@ class BaseFileManager:
         #
         return True
 
-    def required_keys(self, integration_mode):
-        """Required keys for the integration_mode"""
+    def get_required_keys(self, integration_mode):
+        """Return the required keys for the integration_mode"""
         if integration_mode == SCRIPT:
             return SCRIPT_REQUIRED_KEYS
         #
@@ -267,8 +291,22 @@ class Caja(Nautilus):
     """Caja file manager (Nautilus based)"""
 
     name = "caja"
-    config_directory = ".local/share/caja"
-    # capabilities = (ACTION, SCRIPT)
+    config_directory = ".config/caja"
+    capabilities = (ACTION, SCRIPT)
+    explicit_directories = {ACTION: ".local/share/file-manager/actions"}
+    action_template = CAJA_ACTION_TEMPLATE
+    executable = "/usr/bin/caja"
+
+    def install_action(self, target_directory_path, configuration, options):
+        """Install as Nemo action in target path"""
+        check_target_directory(target_directory_path, options)
+        action_name = configuration["name"]
+        target_file_path = target_directory_path / f"{action_name}.desktop"
+        check_target_file(target_file_path, options)
+        target_file_path.write_text(
+            self.template.safe_substitute(configuration),
+            encoding="utf-8",
+        )
 
 
 class Nemo(Nautilus):
@@ -282,7 +320,7 @@ class Nemo(Nautilus):
     executable = "/usr/bin/nemo"
 
     def install_action(self, target_directory_path, configuration, options):
-        """Install as Nemo action in tagret path"""
+        """Install as Nemo action in target path"""
         check_target_directory(target_directory_path, options)
         action_name = configuration["name"]
         target_file_path = target_directory_path / f"{action_name}.nemo_action"
@@ -323,7 +361,7 @@ class Thunar(BaseFileManager):
 #
 
 
-SUPPORTED = (Nautilus, Nemo)
+SUPPORTED = (Caja, Nautilus, Nemo)
 
 
 # vim: fileencoding=utf-8 ts=4 sts=4 sw=4 autoindent expandtab syntax=python:
